"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerateFilesFromGithub = void 0;
const is_cache_expired_1 = __importDefault(require("@lib/cache/is-cache-expired"));
const update_cache_expiration_1 = __importDefault(require("@lib/cache/update-cache-expiration"));
const create_folder_1 = __importDefault(require("@lib/create-folder-if-not-exists/create-folder"));
const download_template_1 = __importDefault(require("@lib/download-template"));
const define_lib_path_1 = __importDefault(require("@/define-lib-path"));
const decompress_1 = __importDefault(require("@lib/unzip-gz-file/decompress"));
const icons_1 = require("@ui/icons");
const print_1 = require("@ui/print");
/**
 * @description get template from github if cache is expired
 * @param props path, templateFolder, fileName, targetName
 * @returns 0 if all gone well and 1 if error
 */
const GenerateFilesFromGithub = async (props) => {
    const destinationPath = (0, define_lib_path_1.default)([props.destinationPath, props.name]);
    const tarPath = (0, define_lib_path_1.default)(['downloads', props.fileTarName]);
    // create folders if not exists
    (0, create_folder_1.default)(tarPath);
    (0, create_folder_1.default)(destinationPath);
    const isExpiredCache = (0, is_cache_expired_1.default)(Object.assign({}, props));
    // download github template as gz
    if (isExpiredCache) {
        await (0, download_template_1.default)(Object.assign(Object.assign({}, props), { tarPath }));
        (0, update_cache_expiration_1.default)(Object.assign({}, props));
    }
    ;
    // unzip file to user folder
    await (0, decompress_1.default)({ zipTarFilePath: tarPath, destinationPath });
    // copy files to user path
    (0, print_1.PrintInfo)(icons_1.folder, 'copying files', `to path: ${destinationPath}`);
    return (0);
};
exports.GenerateFilesFromGithub = GenerateFilesFromGithub;
exports.default = exports.GenerateFilesFromGithub;
//# sourceMappingURL=create.js.map