"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidateInputs = void 0;
const actions_1 = __importDefault(require("@actions/actions"));
const resources_1 = __importDefault(require("@actions/resources"));
const print_1 = require("@ui/print");
/**
 * @description validate each args
 * @param args valid args
 * @returns 0 if all ok else has some invalid input returns 1
 */
const ValidateInputs = (args) => {
    const action = args[0];
    const isValidAction = actions_1.default.includes(action);
    if (!isValidAction) {
        (0, print_1.PrintError)("first arg", `must be a valid option: ${actions_1.default.toString()}`);
        return (1);
    }
    const nameIndex = args.findIndex((arg) => arg === '--name');
    if (nameIndex === -1) {
        (0, print_1.PrintError)("--name", 'arg is required');
        return (1);
    }
    const resourceName = args[nameIndex + 1];
    if (typeof resourceName !== 'string') {
        (0, print_1.PrintError)("--name", 'value arg is required');
        return (1);
    }
    const firstLetterAsciiCode = resourceName.charCodeAt(0);
    if (!(firstLetterAsciiCode >= 65 && firstLetterAsciiCode <= 90) &&
        !(firstLetterAsciiCode >= 97 && firstLetterAsciiCode <= 122)) {
        (0, print_1.PrintError)(resourceName, 'is an invalid name');
        return (1);
    }
    const resource = args[1];
    const isValidResource = resources_1.default.includes(resource);
    if (!isValidResource) {
        (0, print_1.PrintError)(resource, `is not a valid option. see --help`);
        return (1);
    }
    return (0);
};
exports.ValidateInputs = ValidateInputs;
exports.default = exports.ValidateInputs;
//# sourceMappingURL=validate-inputs.js.map