"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Compile = exports.ApplyData = void 0;
const copy_files_1 = require("@lib/copy-files");
const read_file_content_1 = __importDefault(require("./read-file-content"));
const node_path_1 = require("node:path");
const save_data_content_1 = __importDefault(require("./save-data-content"));
const rename_file_1 = __importDefault(require("./rename-file"));
const change_file_extension_1 = __importDefault(require("./change-file-extension"));
/**
 * @description apply data to a file
 * @param file Dirent file
 * @param args as CompileArgs
 * @returns 1 if some conflict occurs and 0 if all ok
 */
const ApplyData = async (file, _a) => {
    var { data, destinationPath } = _a, arg = __rest(_a, ["data", "destinationPath"]);
    return new Promise((ok, fail) => {
        const fileName = file.name;
        const folder = arg.name;
        const targetFolderPath = (0, node_path_1.resolve)(destinationPath, folder, fileName);
        if (fileName === '.git')
            return ok(0);
        if (file.isDirectory()) {
            return (0, exports.Compile)(Object.assign(Object.assign({ data }, arg), { destinationPath: targetFolderPath, name: '' }));
        }
        const isTemplate = fileName.includes('__TEMPLATE__FILE__NAME__');
        if (!isTemplate) {
            return ok(0);
        }
        const buffer = (0, read_file_content_1.default)(targetFolderPath);
        const content = buffer.toString();
        data.forEach((prop) => {
            const key = Object.keys(prop)[0];
            const value = Object.values(prop)[0];
            if (typeof key !== 'string' || typeof value !== 'string') {
                return fail('invalid args');
            }
            const hasPropsToReplace = content.includes(key);
            if (hasPropsToReplace) {
                const result = content.replace(RegExp(key, 'gm'), value);
                (0, save_data_content_1.default)(targetFolderPath, result);
            }
            if (key === '__TEMPLATE__FILE__NAME__') {
                const resultPath = (0, change_file_extension_1.default)(targetFolderPath, value);
                (0, rename_file_1.default)(targetFolderPath, resultPath);
            }
        });
        return ok(0);
    });
};
exports.ApplyData = ApplyData;
/**
 * @description compile data to files
 * @param args CompileArgs
 * @returns void
 */
const Compile = async (_a) => {
    var { data, name } = _a, arg = __rest(_a, ["data", "name"]);
    return new Promise((ok) => {
        const path = (0, node_path_1.resolve)(arg.destinationPath, name);
        const isArray = Array.isArray(data);
        const hasProps = isArray && data.length > 0;
        const files = (0, copy_files_1.ReadDir)(path);
        const existsFiles = files.length > 0;
        if (!hasProps || !existsFiles) {
            return ok(0);
        }
        files.forEach(async (file) => await (0, exports.ApplyData)(file, Object.assign({ data, name }, arg)));
        return ok(0);
    });
};
exports.Compile = Compile;
exports.default = exports.Compile;
//# sourceMappingURL=compile.js.map