"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DownloadTemplate = void 0;
const node_fs_1 = require("node:fs");
const node_https_1 = require("node:https");
const node_fs_2 = require("node:fs");
const node_url_1 = require("node:url");
const print_1 = require("@ui/print");
const icons_1 = require("@ui/icons");
const define_lib_path_1 = __importDefault(require("@/define-lib-path"));
const copy_files_1 = require("@lib/copy-files");
const create_folder_if_not_exists_1 = require("@lib/create-folder-if-not-exists");
/**
 * @description ensure create download folder and delete old tar file
 * @param path tar path
 */
const EnsureFolderAndNewFile = (path) => {
    const downloadFolderPath = (0, define_lib_path_1.default)(['downloads']);
    (0, create_folder_if_not_exists_1.CreateFolderIfNotExists)(downloadFolderPath);
    const exists = (0, copy_files_1.ExistsFile)(path);
    if (exists)
        (0, node_fs_1.rmSync)(path, { recursive: true, force: true });
};
/**
 * @description download template from github
 * @param props resource
 * @returns void
 */
const DownloadTemplate = async (props) => {
    //'https://codeload.github.com/4lessandrodev/form-example/legacy.tar.gz/refs/heads/main'
    return new Promise((ok, fail) => {
        const url = new node_url_1.URL(props.templateUrl);
        const request = (0, node_https_1.get)(url);
        // delete old file and create download folder
        EnsureFolderAndNewFile(props.tarPath);
        request.on('response', (response) => {
            (0, print_1.PrintInfo)(icons_1.hourGlass, 'downloading template', 'fetching ...');
            const out = (0, node_fs_2.createWriteStream)(props.tarPath);
            const status = response.statusCode;
            const message = response.statusMessage;
            if (!status || status !== 200) {
                (0, print_1.PrintError)('Error on download template', message !== null && message !== void 0 ? message : 'connection refused');
                fail(message);
                process.exitCode = 1;
            }
            const onError = (error) => {
                if (error) {
                    (0, print_1.PrintError)('Unexpected error', error.message);
                    fail(message);
                    process.exitCode = 1;
                }
            };
            response.on('error', onError);
            response.pipe(out);
            response.on('end', () => {
                ok(0);
            });
        });
    });
};
exports.DownloadTemplate = DownloadTemplate;
exports.default = exports.DownloadTemplate;
//# sourceMappingURL=index.js.map