"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AggregateHelp = exports.EntityHelp = exports.ValueObjectHelp = exports.MainHelp = void 0;
const colors_1 = require("./colors");
exports.MainHelp = `
	${colors_1.FgGreen}${colors_1.Bright}
	--------- HELP CENTER ---------
	${colors_1.Reset}

	${colors_1.FgBlue}types-ddd [action] [options]${colors_1.Reset}

	${colors_1.Bright}Actions:${colors_1.Reset}
	${colors_1.FgBlue}create${colors_1.Reset}: generate a new resource${colors_1.Reset}
	${colors_1.FgBlue}help | --help${colors_1.Reset}: show help options${colors_1.Reset}
	${colors_1.FgBlue}version | --version${colors_1.Reset}: show cli version${colors_1.Reset}

	${colors_1.Bright}Options:${colors_1.Reset}
	${colors_1.FgBlue}rest-api${colors_1.Reset}: generate a new app based on rest api template${colors_1.Reset}
	${colors_1.FgBlue}microservice | mcs${colors_1.Reset}: generate a new app based on microservice template${colors_1.Reset}
	${colors_1.FgBlue}ms-client | msc${colors_1.Reset}: generate a new app based on microservice client template${colors_1.Reset}
	${colors_1.FgBlue}web-app | wap${colors_1.Reset}: generate a new web app based on next template${colors_1.Reset}
	${colors_1.FgBlue}web-component | wbc${colors_1.Reset}: generate a new react component${colors_1.Reset}
	${colors_1.FgBlue}lambda${colors_1.Reset}: generate a new app based on lambda serverless${colors_1.Reset}
	${colors_1.FgBlue}command | cmd${colors_1.Reset}: generate a new class implementing command pattern${colors_1.Reset}
	${colors_1.FgBlue}ddd-adapter | dad${colors_1.Reset}: generate an adapter from infra to domain${colors_1.Reset}
	${colors_1.FgBlue}ddd-aggregate | dag${colors_1.Reset}: generate an aggregate to a module${colors_1.Reset}
	${colors_1.FgBlue}ddd-entity | den${colors_1.Reset}: generate an entity to a module${colors_1.Reset}
	${colors_1.FgBlue}ddd-event | evt${colors_1.Reset}: generate a domain event handler${colors_1.Reset}
	${colors_1.FgBlue}ddd-model | dmd${colors_1.Reset}: generate a model to a module${colors_1.Reset}
	${colors_1.FgBlue}ddd-module | dmo${colors_1.Reset}: generate a new domain module${colors_1.Reset}
	${colors_1.FgBlue}ddd-repository | dre${colors_1.Reset}: generate a new base repository${colors_1.Reset}
	${colors_1.FgBlue}ddd-value-object | dvo${colors_1.Reset}: generate a new value object${colors_1.Reset}
	${colors_1.FgBlue}use-case | usc${colors_1.Reset}: generate a new use case${colors_1.Reset}

	${colors_1.Bright}Example:${colors_1.Reset}
	${colors_1.FgBlue}types-ddd create rest-api --name example --path ./my-folder
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create dad --name my-adapter --path ./src/modules/payment/adapters
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create lambda --help
	${colors_1.Reset}${colors_1.FgGreen}
	-------------------------------
	${colors_1.Reset}
`;
exports.ValueObjectHelp = `
	${colors_1.FgGreen}${colors_1.Bright}
	--------- HELP CENTER ---------
	${colors_1.Reset}

	${colors_1.Bright}Value Object:${colors_1.Reset}
	- Are only identified by their values, not by their ids (for example money is a value object
	as long as we are not tracking individual banknotes, if we need to track individual 
	banknotes then it should be a banknote entity)
	- Can be used to measure or describe things (name, description, amount, height, date, time, 
	range, address, etc.)
	- You can combine other value types that usually go together into a new value object type, 
	like address (city, street, country, postal code) or ...range, or ...type
	- Prefer to put the behavior on value objects rather than on entities because value objects are
	immutable and do not have side effects (like changing their state or changing the state of any entity)
	- Can be part of an entity
	- Should be immutable, behaviors should not change the state of a value object, 
	but can rather create a new value object (should act similar to C# strings, structs, ints, 
	and other value types)
	- Can be persisted but only as part of an entity, not individually

	${colors_1.Bright}Example:${colors_1.Reset}
	${colors_1.FgBlue}types-ddd create ddd-value-object --name example --path ./my-folder
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create dvo --name example --path ./src/domain
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create dvo --name example
	${colors_1.Reset}${colors_1.FgGreen}
	-------------------------------
	${colors_1.Reset}	
`;
exports.EntityHelp = `
	${colors_1.FgGreen}${colors_1.Bright}
	--------- HELP CENTER ---------
	${colors_1.Reset}

	${colors_1.Bright}Entity:${colors_1.Reset}
	- Live longer than the application, should endure restarts, and are persisted and read 
	from data sources (DB, file system, network, etc.)
	- Have an id (preferably a GUID rather than a DB generated int because business 
	transactions do not rely on persistence, can be persisted after other operations 
	carried out in model's behavior)
	- Have entity semantics (equality and GetHashCode() defined by class name + id)
	- Behavior in an entity mostly orchestrates value objects for a use case
	- Entity class should not have public property setters, setting a property 
	should be a behavior method
	- Entities should not have bidirectional relations (depending on the bounded context, 
	either an egg can have a chicken or a chicken can have eggs, but not both)
	- Entity relations should not reflect the complete set of DB foreign key relationships, 
	should be bare down to the minimum for performing the behavior inside the bounded context
	- Entity relations should not hold a reference to another entity class, it can only keep 
	the id of another entity
	- If a business transaction needs a reference to other entities in relation, 
	aggregates should be used instead (aggregates can hold a reference to other aggregate roots, 
	which are entity classes by definition)

	${colors_1.Bright}Example:${colors_1.Reset}
	${colors_1.FgBlue}types-ddd create ddd-entity --name example --path ./my-folder
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create den --name example --path ./src/domain
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create den --name example
	${colors_1.Reset}${colors_1.FgGreen}
	-------------------------------
	${colors_1.Reset}	
`;
exports.AggregateHelp = `
	${colors_1.FgGreen}${colors_1.Bright}
	--------- HELP CENTER ---------
	${colors_1.Reset}

	${colors_1.Bright}Aggregate:${colors_1.Reset}
	- Encapsulate and are composed of entity classes and value objects that change together
	in a business transaction
	- Aggregates are a transactional graph of model objects
	- Aggregate root should be an entity, an aggregate can even be a single entity
	- Aggregate can keep a reference to other aggregate roots, but not to other entity 
	classes which are not aggregate roots themselves
	- Aggregate should not keep a reference to other aggregate root entity classes 
	if those other entities do not change together with this aggregate root entity
	- Aggregate can also keep the id of another entity, but keeping too many foreign key
	ids is a code smell (why?)
	- If deleting an entity has a cascade effect on the other entities referenced 
	by class in the object graph, these entities are part of the same aggregate, 
	if not, they should not be inside this aggregate


	${colors_1.Bright}Example:${colors_1.Reset}
	${colors_1.FgBlue}types-ddd create ddd-aggregate --name example --path ./my-folder
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create dag --name example --path ./src/domain
	${colors_1.Reset}${colors_1.FgGreen}
	${colors_1.FgBlue}types-ddd create dag --name example
	${colors_1.Reset}${colors_1.FgGreen}
	-------------------------------
	${colors_1.Reset}	
`;
//# sourceMappingURL=help-center.js.map